import { __decorate, __extends } from 'tslib';
import { ChangeDetectorRef, Input, ViewChild, Component, ɵɵdefineInjectable, Injectable, NgModule } from '@angular/core';
import { HammerGestureConfig, BrowserModule, HammerModule, HAMMER_GESTURE_CONFIG } from '@angular/platform-browser';
import * as Hammer from 'hammerjs';
import { Pan } from 'hammerjs';

var HammerjsCarouselComponent = /** @class */ (function () {
    function HammerjsCarouselComponent(cdRef) {
        this.cdRef = cdRef;
        this.activeSlide = 0;
        this.sensitivity = 10;
    }
    Object.defineProperty(HammerjsCarouselComponent.prototype, "slides", {
        get: function () {
            return this.slidesInternal;
        },
        set: function (value) {
            this.slidesInternal = value;
            if (this.slides != null) {
                this.slideCount = this.slides.length;
            }
            else {
                this.slideCount = 0;
            }
        },
        enumerable: true,
        configurable: true
    });
    HammerjsCarouselComponent.prototype.ngOnInit = function () {
        this.isTouchDevice = 'ontouchstart' in window;
    };
    HammerjsCarouselComponent.prototype.ngAfterViewChecked = function () {
        var sliderWrapperElement = this.sliderWrapper.nativeElement;
        this.width = sliderWrapperElement.offsetWidth;
        this.sensitivity = this.width / 40;
        this.cdRef.detectChanges();
    };
    HammerjsCarouselComponent.prototype.onPan = function (e) {
        if (e.velocityX === 0 || Math.abs(e.velocityY) > Math.abs(e.velocityX)) {
            // Vertical scroll
            return;
        }
        var percentage = 100 / this.slideCount * e.deltaX / window.innerWidth;
        var transformPercentage = percentage - 100 / this.slideCount * this.activeSlide;
        this.sliderTransformStyle = 'translateX( ' + transformPercentage + '% )';
        if (e.isFinal) {
            if (e.velocityX > 1) {
                this.goToSlide(this.activeSlide - 1);
            }
            else if (e.velocityX < -1) {
                this.goToSlide(this.activeSlide + 1);
            }
            else {
                if (percentage <= -(this.sensitivity / this.slideCount)) {
                    this.goToSlide(this.activeSlide + 1);
                }
                else if (percentage >= (this.sensitivity / this.slideCount)) {
                    this.goToSlide(this.activeSlide - 1);
                }
                else {
                    this.goToSlide(this.activeSlide);
                }
            }
        }
    };
    HammerjsCarouselComponent.prototype.previousSlide = function () {
        var slideIndex = this.activeSlide - 1;
        if (slideIndex < 0) {
            this.goToSlide(this.slideCount - 1);
        }
        else {
            this.goToSlide(slideIndex);
        }
    };
    HammerjsCarouselComponent.prototype.nextSlide = function () {
        var slideIndex = this.activeSlide + 1;
        if (slideIndex === this.slideCount) {
            this.goToSlide(0);
        }
        else {
            this.goToSlide(slideIndex);
        }
    };
    HammerjsCarouselComponent.prototype.goToSlide = function (slideNumber) {
        var _this = this;
        if (slideNumber < 0) {
            this.activeSlide = 0;
        }
        else if (slideNumber > this.slideCount - 1) {
            this.activeSlide = this.slideCount - 1;
        }
        else {
            this.activeSlide = slideNumber;
        }
        this.isAnimating = true;
        var percentage = -(100 / this.slideCount) * this.activeSlide;
        this.sliderTransformStyle = 'translateX(' + percentage + '%)';
        clearTimeout(this.animatingTimeout);
        this.animatingTimeout = setTimeout(function () { return _this.isAnimating = false; }, 400);
    };
    HammerjsCarouselComponent.prototype.isActive = function (index) {
        return this.activeSlide === index;
    };
    HammerjsCarouselComponent.prototype.getWidthStyle = function () {
        if (this.width == null) {
            return null;
        }
        return (this.width / 13) + 'px';
    };
    HammerjsCarouselComponent.prototype.getMarginStyle = function () {
        if (this.width == null) {
            return null;
        }
        return (this.width / 30) + 'px';
    };
    HammerjsCarouselComponent.ctorParameters = function () { return [
        { type: ChangeDetectorRef }
    ]; };
    __decorate([
        Input()
    ], HammerjsCarouselComponent.prototype, "slides", null);
    __decorate([
        ViewChild('sliderWrapper')
    ], HammerjsCarouselComponent.prototype, "sliderWrapper", void 0);
    HammerjsCarouselComponent = __decorate([
        Component({
            // tslint:disable-next-line:component-selector
            selector: 'hammerjs-carousel',
            template: "\n  <div class=\"slider-wrapper\" #sliderWrapper>\n    <div class=\"slider\" (pan)=\"onPan($event)\" [style.transform]=\"sliderTransformStyle\" [style.width]=\"slideCount + '00%'\"\n         [ngClass]=\"{ 'is-animating': isAnimating }\">\n      <div class=\"slider-panel\" *ngFor=\"let slide of slides\" [style.background-image]=\"'url(' + slide + ')'\"></div>\n    </div>\n    <div class=\"slider-button left\" *ngIf=\"!isTouchDevice && slides?.length > 1\" (click)=\"previousSlide()\">\n        <svg class=\"chevron\" [style.width]=\"getWidthStyle()\" [style.margin-left]=\"getMarginStyle()\"\n        xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"17 15 13 20\" enable-background=\"new 17 15 13 20\" fill=\"#fff\">\n          <path d=\"M27.3 34.7L17.6 25l9.7-9.7 1.4 1.4-8.3 8.3 8.3 8.3z\"/>\n        </svg>\n    </div>\n    <div class=\"slider-button right\" *ngIf=\"!isTouchDevice && slides?.length > 1\" (click)=\"nextSlide()\">\n      <svg class=\"chevron right\" [style.width]=\"getWidthStyle()\" [style.margin-right]=\"getMarginStyle()\"\n      xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"17 15 13 20\" enable-background=\"new 17 15 13 20\" fill=\"#fff\">\n          <path d=\"M27.3 34.7L17.6 25l9.7-9.7 1.4 1.4-8.3 8.3 8.3 8.3z\"/>\n        </svg>\n    </div>\n    <div class=\"slider-pagination\" *ngIf=\"slides?.length > 1\">\n      <div *ngFor=\"let slide of slides; index as index;\" (click)=\"goToSlide(index)\">\n        <div class=\"slider-page\" [ngClass]=\"{ 'is-active': isActive(index) }\"></div>\n      </div>\n    </div>\n  </div>\n  ",
            styles: [".slider-wrapper{overflow:hidden;width:100%;height:100%;position:relative}.slider{display:-webkit-box;display:flex;height:100%}.slider.is-animating{-webkit-transition:-webkit-transform .4s cubic-bezier(.5,0,.5,1);transition:transform .4s cubic-bezier(.5,0,.5,1);transition:transform .4s cubic-bezier(.5,0,.5,1),-webkit-transform .4s cubic-bezier(.5,0,.5,1)}.slider-panel{width:100%;background-position:center center;background-repeat:no-repeat;background-size:cover}.slider-button{position:absolute;opacity:.7;height:100%;top:0;width:50%;cursor:pointer}.slider-button:hover{color:#fff;opacity:1}.slider-button.left{left:0}.slider-button.left:hover{background:-webkit-gradient(linear,right top,left top,from(rgba(255,255,255,0)),to(rgba(255,255,255,.3)));background:linear-gradient(270deg,rgba(255,255,255,0) 0,rgba(255,255,255,.3) 100%)}.slider-button.right{right:0}.slider-button.right:hover{background:-webkit-gradient(linear,left top,right top,from(rgba(255,255,255,0)),to(rgba(255,255,255,.3)));background:linear-gradient(90deg,rgba(255,255,255,0) 0,rgba(255,255,255,.3) 100%)}.slider-button .chevron{position:absolute;top:50%;-webkit-transform:translateY(-50%);transform:translateY(-50%)}.slider-button .chevron.right{right:0;-webkit-transform:translateY(-50%) rotate(180deg);transform:translateY(-50%) rotate(180deg)}.slider-pagination{bottom:6.25%;left:0;position:absolute;text-align:center;width:100%}.slider-pagination>div{padding:4px;display:inline-block;cursor:pointer}.slider-pagination .slider-page{border-radius:50%;box-shadow:0 0 0 2px rgba(255,255,255,.75);height:6px;-webkit-transition:background-color 250ms;transition:background-color 250ms;width:6px}.slider-pagination .slider-page.is-active{background-color:rgba(255,255,255,.75)}"]
        })
    ], HammerjsCarouselComponent);
    return HammerjsCarouselComponent;
}());

var GestureConfigService = /** @class */ (function (_super) {
    __extends(GestureConfigService, _super);
    function GestureConfigService() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GestureConfigService.prototype.buildHammer = function (element) {
        var mc = new Hammer(element, {
            touchAction: 'pan-y',
            recognizers: [
                [Pan],
            ]
        });
        return mc;
    };
    GestureConfigService.ɵprov = ɵɵdefineInjectable({ factory: function GestureConfigService_Factory() { return new GestureConfigService(); }, token: GestureConfigService, providedIn: "root" });
    GestureConfigService = __decorate([
        Injectable({
            providedIn: 'root'
        })
    ], GestureConfigService);
    return GestureConfigService;
}(HammerGestureConfig));

var HammerjsCarouselModule = /** @class */ (function () {
    function HammerjsCarouselModule() {
    }
    HammerjsCarouselModule = __decorate([
        NgModule({
            declarations: [HammerjsCarouselComponent],
            imports: [
                BrowserModule, HammerModule
            ],
            exports: [HammerjsCarouselComponent],
            providers: [{
                    provide: HAMMER_GESTURE_CONFIG,
                    useClass: GestureConfigService
                }]
        })
    ], HammerjsCarouselModule);
    return HammerjsCarouselModule;
}());

/*
 * Public API Surface of ngx-hammerjs-carousel
 */

/**
 * Generated bundle index. Do not edit.
 */

export { HammerjsCarouselComponent, HammerjsCarouselModule, GestureConfigService as ɵa };
//# sourceMappingURL=ngx-hammerjs-carousel.js.map
